@@ -104,13 +104,10 @@ nsXHTMLContentSerializer::Init(PRUint32 aFlags, PRUint32 aWrapColumn,
   // The previous version of the HTML serializer did implicit wrapping
   // when there is no flags, so we keep wrapping in order to keep
   // compatibility with the existing calling code
-  // XXXLJ perhaps we should remove these two default settings later ?
+  // XXXLJ perhaps should we remove this default settings later ?
   if (aFlags & nsIDocumentEncoder::OutputFormatted ) {
       aFlags = aFlags | nsIDocumentEncoder::OutputWrap;
   }
-  else if (!(aFlags & nsIDocumentEncoder::OutputRaw)) {
-      aFlags = aFlags | nsIDocumentEncoder::OutputWrap;
-  }
 
   nsresult rv;
   rv = nsXMLContentSerializer::Init(aFlags, aWrapColumn, aCharSet, aIsCopying, aRewriteEncodingDeclaration);
@@ -185,7 +182,9 @@ nsXHTMLContentSerializer::AppendText(nsIDOMText* aText,
     PRInt32 lastNewlineOffset = kNotFound;
     if (HasLongLines(data, lastNewlineOffset)) {
       // We have long lines, rewrap
+      mDoWrap = PR_TRUE;
       AppendToStringWrapped(data, aStr);
+      mDoWrap = PR_FALSE;
     }
     else {
       AppendToStringConvertLF(data, aStr);
@@ -469,18 +468,26 @@ nsXHTMLContentSerializer::AppendEndOfElementStart(nsIDOMElement *aOriginalElemen
     return;
   }
 
-  nsIParserService* parserService = nsContentUtils::GetParserService();
+  nsCOMPtr<nsIContent> content = do_QueryInterface(aOriginalElement);
 
-  if (parserService) {
-    PRBool isContainer;
-    parserService->IsContainer(parserService->HTMLAtomTagToId(aName),
-                             isContainer);
-    if (!isContainer) {
-      // for backward compatibility with HTML 4 user agents
-      // only non-container HTML elements can be closed immediatly,
-      // and a space is added before />
-      AppendToString(NS_LITERAL_STRING(" />"), aStr);
-      return;
+  // for non empty elements, even if they are not a container, we always
+  // serialize their content, because the XHTML element could contain non XHTML
+  // nodes useful in some context, like in an XSLT stylesheet
+  if (HasNoChildren(content)) {
+
+    nsIParserService* parserService = nsContentUtils::GetParserService();
+  
+    if (parserService) {
+      PRBool isContainer;
+      parserService->IsContainer(parserService->HTMLAtomTagToId(aName),
+                                 isContainer);
+      if (!isContainer) {
+        // for backward compatibility with HTML 4 user agents
+        // only non-container HTML elements can be closed immediatly,
+        // and a space is added before />
+        AppendToString(NS_LITERAL_STRING(" />"), aStr);
+        return;
+      }
     }
   }
   AppendToString(kGreaterThan, aStr);
@@ -613,17 +620,19 @@ nsXHTMLContentSerializer::CheckElementEnd(nsIContent * aContent,
       }
     }
 
-    nsIParserService* parserService = nsContentUtils::GetParserService();
+    if (HasNoChildren(aContent)) {
+      nsIParserService* parserService = nsContentUtils::GetParserService();
 
-    if (parserService) {
-      PRBool isContainer;
+      if (parserService) {
+        PRBool isContainer;
 
-      parserService->IsContainer(parserService->HTMLAtomTagToId(name),
-                                 isContainer);
-      if (!isContainer) {
-        // non-container HTML elements are already closed,
-        // see AppendEndOfElementStart
-        return PR_FALSE;
+        parserService->IsContainer(parserService->HTMLAtomTagToId(name),
+                                   isContainer);
+        if (!isContainer) {
+          // non-container HTML elements are already closed,
+          // see AppendEndOfElementStart
+          return PR_FALSE;
+        }
       }
     }
     // for backward compatibility with old HTML user agents,
@@ -667,31 +676,6 @@ nsXHTMLContentSerializer::AppendToString(const nsAString& aStr,
   nsXMLContentSerializer::AppendToString(aStr, aOutputStr);
 }
 
-
-static const PRUint16 kValNBSP = 160;
-static const char kEntityNBSP[] = "nbsp";
-
-static const PRUint16 kGTVal = 62;
-static const char* kEntities[] = {
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "amp", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "lt", "", "gt"
-};
-
-static const char* kAttrEntities[] = {
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "quot", "", "", "", "amp", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "", "", "", "", "", "", "", "", "", "",
-  "lt", "", "gt"
-};
-
 void
 nsXHTMLContentSerializer::AppendAndTranslateEntities(const nsAString& aStr,
                                                      nsAString& aOutputStr)
@@ -704,105 +688,8 @@ nsXHTMLContentSerializer::AppendAndTranslateEntities(const nsAString& aStr,
     aOutputStr.Append(aStr);
     return;
   }
-
-  if (mFlags & (nsIDocumentEncoder::OutputEncodeBasicEntities  |
-                nsIDocumentEncoder::OutputEncodeLatin1Entities |
-                nsIDocumentEncoder::OutputEncodeHTMLEntities   |
-                nsIDocumentEncoder::OutputEncodeW3CEntities)) {
-    nsIParserService* parserService = nsContentUtils::GetParserService();
-
-    if (!parserService) {
-      NS_ERROR("Can't get parser service");
-      return;
-    }
-
-    nsReadingIterator<PRUnichar> done_reading;
-    aStr.EndReading(done_reading);
-
-    // for each chunk of |aString|...
-    PRUint32 advanceLength = 0;
-    nsReadingIterator<PRUnichar> iter;
-
-    const char **entityTable = mInAttribute ? kAttrEntities : kEntities;
-
-    for (aStr.BeginReading(iter);
-          iter != done_reading;
-          iter.advance(PRInt32(advanceLength))) {
-      PRUint32 fragmentLength = iter.size_forward();
-      PRUint32 lengthReplaced = 0; // the number of UTF-16 codepoints
-                                    //  replaced by a particular entity
-      const PRUnichar* c = iter.get();
-      const PRUnichar* fragmentStart = c;
-      const PRUnichar* fragmentEnd = c + fragmentLength;
-      const char* entityText = nsnull;
-      nsCAutoString entityReplacement;
-      char* fullEntityText = nsnull;
-
-      advanceLength = 0;
-      // for each character in this chunk, check if it
-      // needs to be replaced
-      for (; c < fragmentEnd; c++, advanceLength++) {
-        PRUnichar val = *c;
-        if (val == kValNBSP) {
-          entityText = kEntityNBSP;
-          break;
-        }
-        else if ((val <= kGTVal) && (entityTable[val][0] != 0)) {
-          entityText = entityTable[val];
-          break;
-        } else if (val > 127 &&
-                  ((val < 256 &&
-                    mFlags & nsIDocumentEncoder::OutputEncodeLatin1Entities) ||
-                    mFlags & nsIDocumentEncoder::OutputEncodeHTMLEntities)) {
-          parserService->HTMLConvertUnicodeToEntity(val, entityReplacement);
-
-          if (!entityReplacement.IsEmpty()) {
-            entityText = entityReplacement.get();
-            break;
-          }
-        }
-        else if (val > 127 &&
-                  mFlags & nsIDocumentEncoder::OutputEncodeW3CEntities &&
-                  mEntityConverter) {
-          if (NS_IS_HIGH_SURROGATE(val) &&
-              c + 1 < fragmentEnd &&
-              NS_IS_LOW_SURROGATE(*(c + 1))) {
-            PRUint32 valUTF32 = SURROGATE_TO_UCS4(val, *(++c));
-            if (NS_SUCCEEDED(mEntityConverter->ConvertUTF32ToEntity(valUTF32,
-                              nsIEntityConverter::entityW3C, &fullEntityText))) {
-              lengthReplaced = 2;
-              break;
-            }
-            else {
-              advanceLength++;
-            }
-          }
-          else if (NS_SUCCEEDED(mEntityConverter->ConvertToEntity(val,
-                                nsIEntityConverter::entityW3C, 
-                                &fullEntityText))) {
-            lengthReplaced = 1;
-            break;
-          }
-        }
-      }
-
-      aOutputStr.Append(fragmentStart, advanceLength);
-      if (entityText) {
-        aOutputStr.Append(PRUnichar('&'));
-        AppendASCIItoUTF16(entityText, aOutputStr);
-        aOutputStr.Append(PRUnichar(';'));
-        advanceLength++;
-      }
-      // if it comes from nsIEntityConverter, it already has '&' and ';'
-      else if (fullEntityText) {
-        AppendASCIItoUTF16(fullEntityText, aOutputStr);
-        nsMemory::Free(fullEntityText);
-        advanceLength += lengthReplaced;
-      }
-    }
-  } else {
-    nsXMLContentSerializer::AppendAndTranslateEntities(aStr, aOutputStr);
-  }
+ 
+  nsXMLContentSerializer::AppendAndTranslateEntities(aStr, aOutputStr);
 }
 
 PRBool
@@ -1196,3 +1083,22 @@ nsXHTMLContentSerializer::IsFirstChildOfOL(nsIDOMElement* aElement)
   else
     return PR_FALSE;
 }
+
+PRBool
+nsXHTMLContentSerializer::HasNoChildren(nsIContent * aContent) {
+
+  PRUint32 i, childCount = aContent->GetChildCount();
+
+  for (i = 0; i < childCount; ++i) {
+
+    nsIContent* child = aContent->GetChildAt(i);
+
+    if (!child->IsNodeOfType(nsINode::eTEXT))
+      return PR_FALSE;
+
+    if (child->TextLength())
+      return PR_FALSE;
+  }
+
+  return PR_TRUE;
+}
