@@ -40,18 +40,48 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '13.5.4.20.js';
+gTestfile = '13.5.4.2.js';
 
-START("13.5.4.20 - XMLList toString()");
+START("13.5.4.2 - XMLList attribute()");
 
-TEST(1, true, XMLList.prototype.hasOwnProperty("toString"));
-   
-x = <><alpha>one</alpha></>;
+TEST(1, true, XMLList.prototype.hasOwnProperty("attribute"));
 
-TEST(2, "one", x.toString());
+// Test with list of size 0
+emps = new XMLList();
+TEST(2, "xml", typeof(emps.attribute("id")));
+TEST_XML(3, "", emps.attribute("id"));
 
-x = <><alpha>one</alpha><bravo>two</bravo></>;
+// Test with list of size 1
+emps += <employee id="0"><name>Jim</name><age>25</age></employee>;
 
-TEST(3, "<alpha>one</alpha>\n<bravo>two</bravo>", x.toString());
+TEST(4, "xml", typeof(emps.attribute("id")));
+TEST_XML(5, 0, emps.attribute("id"));
+
+// Test with list of size > 1
+emps += <employee id="1"><name>Joe</name><age>20</age></employee>;
+TEST(6, "xml", typeof(emps.attribute("id")));
+
+correct = new XMLList();
+correct += new XML("0");
+correct += new XML("1");
+TEST(7, correct, emps.attribute("id"));
+
+// Test one that doesn't exist - should return empty XMLList
+TEST(8, "xml", typeof(emps.attribute("foobar")));
+
+// Test args of null and undefined
+try {
+  emps.attribute(null);
+  SHOULD_THROW(9);
+} catch (ex) {
+  TEST(9, "TypeError", ex.name);
+}
+
+try {
+  emps.attribute(undefined);
+  SHOULD_THROW(10);
+} catch (ex) {
+  TEST(10, "TypeError", ex.name);
+}
 
 END();
\ No newline at end of file
