@@ -36,43 +36,51 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '15.9.1.13-1.js';
+gTestfile = '15.9.2.2-1.js';
 
 /**
-   File Name:          15.9.1.13-1.js
-   ECMA Section:       15.9.1.1 MakeDate(day, time)
-   Description:
+   File Name:          15.9.2.2.js
+   ECMA Section:       15.9.2.2 Date constructor used as a function
+   Date( year, month, date, hours, minutes, seconds )
+   Description:        The arguments are accepted, but are completely ignored.
+   A string is created and returned as if by the
+   expression (new Date()).toString().
 
-   The operator MakeDate calculates a number of milliseconds from its
-   two arguments, which must be ECMAScript number values. This
-   operator functions as follows:
+   Author:             christine@netscape.com
+   Date:               28 october 1997
+   Version:            9706
 
-   1. If day is not finite or time is not finite, return NaN.
-
-   2. Compute day * msPerDay + time.
-
-   3. Return Result(2).
 */
+var VERSION = 9706;
+startTest();
+var SECTION = "15.9.2.2";
+var TOLERANCE = 100;
+var TITLE = "The Date Constructor Called as a Function";
 
-new TestCase( SECTION,
-              "MakeDate(Number.POSITIVE_INFINITY, 0)",
-              Number.NaN,
-              MakeDate(Number.POSITIVE_INFINITY, 0));
+writeHeaderToLog(SECTION+" "+TITLE );
 
-new TestCase( SECTION,
-              "MakeDate(Number.NEGATIVE_INFINITY, 0)",
-              Number.NaN,
-              MakeDate(Number.NEGATIVE_INFINITY, 0));
+// allow up to 1 second difference due to possibility
+// the date may change by 1 second in between calls to Date
 
-new TestCase( SECTION,
-              "MakeDate(0, Number.POSITIVE_INFINITY)",
-              Number.NaN,
-              MakeDate(0, Number.POSITIVE_INFINITY));
+var d1;
+var d2;
 
-new TestCase( SECTION,
-              "MakeDate(0, Number.NEGATIVE_INFINITY)",
-              Number.NaN,
-              MakeDate(0, Number.NEGATIVE_INFINITY));
+// Dates around 1970
+
+d1 = new Date();
+d2 = Date.parse(Date(1970,0,1,0,0,0));
+new TestCase(SECTION, "Date(1970,0,1,0,0,0)", true, d2 - d1 <= 1000);
+
+d1 = new Date();
+d2 = Date.parse(Date(1969,11,31,15,59,59));
+new TestCase(SECTION, "Date(1969,11,31,15,59,59)", true, d2 - d1 <= 1000);
+
+d1 = new Date();
+d2 = Date.parse(Date(1969,11,31,16,0,0));
+new TestCase(SECTION, "Date(1969,11,31,16,0,0)", true, d2 - d1 <= 1000);
+
+d1 = new Date();
+d2 = Date.parse(Date(1969,11,31,16,0,1));
+new TestCase(SECTION, "Date(1969,11,31,16,0,1)", true, d2 - d1 <= 1000);
 
 test();
-
