@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2006
+ * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s):
+ * Contributor(s): Jesse Ruderman
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,14 +35,12 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-360969-01.js';
+var gTestfile = 'regress-416737-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 360969;
-var summary = '2^17: local var';
-var actual = 'No Crash';
-var expect = 'No Crash';
-
-var global = this;
+var BUGNUMBER = 416737;
+var summary = 'Do not assert: *pc == JSOP_GETARG';
+var actual = '';
+var expect = '';
 
 //-----------------------------------------------------------------------------
 test();
@@ -53,22 +51,11 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  var start = new Date();
-  var p;
-  var i;
-  var limit = 2 << 16;
 
-  for (var i = 0; i < limit; i++)
-  {
-    eval('var pv;');
-  }
+  (function() { (function([]){ function n(){} })(1) });
 
   reportCompare(expect, actual, summary);
 
-  var stop = new Date();
-
-  print('Elapsed time: ' + Math.floor((stop - start)/1000) + ' seconds');
-
   exitFunc ('test');
 }
+
