@@ -47,6 +47,7 @@
 #include "nsMIMEInfoUnix.h"
 #include "nsGNOMERegistry.h"
 #include "nsIGnomeVFSService.h"
+#include "nsAutoPtr.h"
 #ifdef MOZ_ENABLE_DBUS
 #include "nsDBusHandlerApp.h"
 #endif
@@ -74,12 +75,14 @@ NS_IMETHODIMP
 nsMIMEInfoUnix::GetHasDefaultHandler(PRBool *_retval)
 {
   *_retval = PR_FALSE;
-  nsCOMPtr<nsIGnomeVFSService> vfs = do_GetService(NS_GNOMEVFSSERVICE_CONTRACTID);
-  if (vfs) {
-    nsCOMPtr<nsIGnomeVFSMimeApp> app;
-    if (NS_SUCCEEDED(vfs->GetAppForMimeType(mType, getter_AddRefs(app))) && app)
-      *_retval = PR_TRUE;
+  nsRefPtr<nsMIMEInfoBase> mimeInfo = nsGNOMERegistry::GetFromType(mType);
+  if (!mimeInfo) {
+    nsCAutoString ext;
+    GetPrimaryExtension(ext);
+    mimeInfo = nsGNOMERegistry::GetFromExtension(ext);
   }
+  if (mimeInfo)
+    *_retval = PR_TRUE;
 
   if (*_retval)
     return NS_OK;
@@ -115,6 +118,19 @@ nsMIMEInfoUnix::LaunchDefaultWithFile(nsIFile *aFile)
       return app->Launch(nativePath);
   }
 
+  // If we haven't got an app we try to get a valid one by searching for the
+  // extension mapped type
+  nsRefPtr<nsMIMEInfoBase> mimeInfo = nsGNOMERegistry::GetFromExtension(nativePath);
+  if (mimeInfo) {
+    nsCAutoString type;
+    mimeInfo->GetType(type);
+    if (vfs) {
+      nsCOMPtr<nsIGnomeVFSMimeApp> app;
+      if (NS_SUCCEEDED(vfs->GetAppForMimeType(type, getter_AddRefs(app))) && app)
+        return app->Launch(nativePath);
+    }
+  }
+
   if (!mDefaultApplication)
     return NS_ERROR_FILE_NOT_FOUND;
 
